propagation

package
v0.4.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 6, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ExtractTraceContext

func ExtractTraceContext(req *http.Request) context.Context

ExtractTraceContext extracts trace context from HTTP request headers into the context. If req is nil, returns the background context.

func InjectTraceContext

func InjectTraceContext(ctx context.Context, req *http.Request)

InjectTraceContext injects the current trace context into the HTTP request headers. If req is nil, this function is a no-op to prevent panics.

Types

This section is empty.

Jump to